/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HostSetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The host set description.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set#description HostSet#description}
    */
    readonly description?: string;
    /**
    * The catalog for the host set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set#host_catalog_id HostSet#host_catalog_id}
    */
    readonly hostCatalogId: string;
    /**
    * The list of host IDs contained in this set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set#host_ids HostSet#host_ids}
    */
    readonly hostIds?: string[];
    /**
    * The host set name. Defaults to the resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set#name HostSet#name}
    */
    readonly name?: string;
    /**
    * The type of host set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set#type HostSet#type}
    */
    readonly type: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set boundary_host_set}
*/
export declare class HostSet extends cdktf.TerraformResource {
    static readonly tfResourceType = "boundary_host_set";
    /**
    * Generates CDKTF code for importing a HostSet resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HostSet to import
    * @param importFromId The id of the existing HostSet that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HostSet to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.12/docs/resources/host_set boundary_host_set} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HostSetConfig
    */
    constructor(scope: Construct, id: string, config: HostSetConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _hostCatalogId?;
    get hostCatalogId(): string;
    set hostCatalogId(value: string);
    get hostCatalogIdInput(): string | undefined;
    private _hostIds?;
    get hostIds(): string[];
    set hostIds(value: string[]);
    resetHostIds(): void;
    get hostIdsInput(): string[] | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
